#!/bin/gnuplot

set datafile separator ","
set output 'plot.pdf' 


# Check if the separator is a "," or ";". We want to have at least two columns, so we'll test:
fncumulated='../data/aai_users_per_centre/data_cumulated.csv'
stats fncumulated nooutput
print "Detected ".STATS_columns." columns."

set yrange [0:*]

set xdata time
set timefmt "%Y-%m-%d %H:%M"
set format x "%Y-%m-%d"
set xrange ["2019-07-01":"2023-04-01"]
set grid 
set xtics rotate by 45
set key top left


set terminal pdf  color enhanced size 7,5 dashed
if (!exists("MP_LEFT"))   MP_LEFT = .1
if (!exists("MP_RIGHT"))  MP_RIGHT = .95
if (!exists("MP_BOTTOM")) MP_BOTTOM = .14
if (!exists("MP_TOP"))    MP_TOP = .95
if (!exists("MP_xGAP"))   MP_xGAP = 0.1
if (!exists("MP_yGAP"))   MP_yGAP = 0.02

set multiplot layout 2,2 columnsfirst margins screen MP_LEFT, MP_RIGHT, MP_BOTTOM, MP_TOP spacing screen MP_xGAP, MP_yGAP

set linetype 2 dashtype 2

set key bottom left
set xtics textcolor rgbcolor "white"
set ylabel "{/Arial:Bold B2a}: AAI-connected centres \n (incl head office) in AAI"
set yrange [0:20]
plot '../stats/aai/aai_centers.csv' u 1:($2>0?$2:1/0)   w lp pt 7 ps 0.5 lc black notitle ,\
     ''                             u 1:($2<=11?$2:1/0) w lp pt 6 ps 0.5 lc black lt 2 notitle
set yrange [0:*]

set timefmt "%Y-%m-%d %H:%M"
set xtics textcolor rgbcolor "black" offset -4,-3.5
set ylabel '{/Arial:Bold B2c}: Registered end users'
set key top inside font "Helvetica,9" reverse Left
set label "No centre-\nspecific\ndata available" at (2021.55-1970)*365.25*24*3600,2000 center font "Helvetica,9"
plot '../data/aai_users/data_plot.csv' u 1:($2>=5790?$2:1/0) w filledcurves x1 lc rgb "#aaaacc" title 'Non Helmholtz IdP' ,\
     '../data/aai_users/data_plot.csv' u 1:2 w lines lt 1 lw 2 lc rgb "#000000" notitle ,\
     for [i=STATS_columns:2:-1] fncumulated u 1:i w filledcurves x1 title columnheader
unset label

set timefmt "%d.%m.%y"
set xtics textcolor rgbcolor "white"
set ylabel "{/Arial:Bold B2b}: AAI-connected services \n (incl. \"associated services\")"
plot '../stats/aai/aai_services.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle

set key top left
set timefmt "%d.%m.%Y"
set xtics textcolor rgbcolor "black" offset -4,-3.5
set ylabel '{/Arial:Bold B2d}: Registered top level VOs'
plot '../stats/aai/aai_vo.csv' u 1:2 w lp pt 7 ps 0.5 lt 1 lc black notitle
set timefmt "%Y-%m-%d %H:%M"
              
              
unset multiplot

set multiplot layout 1,1 columnsfirst margins screen MP_LEFT, MP_RIGHT, MP_BOTTOM, MP_TOP spacing screen MP_xGAP, MP_yGAP
set logscale y
set yrange [10:20000]
set timefmt "%d.%m.%Y"
set ylabel '{/Arial:Bold B2c}: Registered end users'
plot '../stats/aai/aai_users.csv' u 1:2 w lp pt 7 ps 0.5 lc black notitle
unset logscale y
unset multiplot
